// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// Copyright 2016 and onwards Google, Inc.
//
// For general information on the Pynini grammar compilation library, see
// pynini.opengrm.org.

#include "split.h"

namespace strings {

std::vector<string> Split(const string &str, char separator) {
  std::vector<string> tokens;
  auto left = str.begin();
  auto end = str.end();
  auto not_separator = [separator](char ch){ return ch == separator; };
  while (true) {
    left = std::find_if_not(left, end, not_separator);
    if (left == end) break;
    auto right = std::find(left, end, separator);
    tokens.emplace_back(string(left, right));
    left = right;
  }
  return std::move(tokens);
}

}  // namespace strings
